/**
   Copyright (C) 2006 by Alexei Krasnopolski

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/
package com.ak.osgi.service.rmi.entrant;

import java.rmi.RMISecurityManager;
import java.rmi.RemoteException;

import org.knopflerfish.service.log.LogRef;
import org.osgi.framework.BundleContext;

import com.ak.osgi.service.rmi.http.StubDownloader;
import com.ak.osgi.service.rmi.utility.BundleProperties;

/**
 * The <tt>Activator</tt> class is a start point of the bundle deploying
 *
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 * @version 1.0.0
 */
public class Activator implements com.ak.osgi.service.rmi.Activator
{
  private static BundleContext bc = null;
  private static Client rmiClient = null;
  private static StubDownloader downLoader = null;
  static LogRef log;

  /**
   * @see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
   */
  public void start( BundleContext context ) throws Exception
  {
    Activator.bc = context;
    
    Activator.log = new LogRef( bc );

    if (System.getSecurityManager() == null) 
    {
      System.setSecurityManager(new RMISecurityManager());
      log.info( "New RMI security manager is set." );
    }
    downLoader = new StubDownloader( bc );
    downLoader.register();

    BundleProperties bp = new BundleProperties( this );
    
    try
    {
      rmiClient = new Client( bp.getRemoteHost(), bp.getRemoteRegistryPort(), this );
      rmiClient.startOpening();
    }
    catch( RemoteException e )
    {
      log.error( "Can not make an instance of Client." );
      throw new Exception( "RMI Entrant exception : can not create Client [" + e.toString() + "]");
    }

    log.info( "RMI Client start." );
  }

  /**
   * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
   */
  public void stop( BundleContext context ) throws Exception
  {
    rmiClient.close(); 
    downLoader.unregister();
    log.info( "RMI Client stop." );
    log.close();

    Activator.bc = null;
    rmiClient = null;
    downLoader = null;
    log = null;
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.Activator#getLogger()
   */ 
  
  public LogRef getLogger()
  {
    return log;
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.Activator#getBundleContext()
   */ 
  
  public BundleContext getBundleContext()
  {
    return bc;
  }

}
