/*
 * Created on Aug 23, 2005
 *
 */
/**
   Copyright (C) 2006 by Alexei Krasnopolski

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/
package com.ak.osgi.service.rmi.gate;

import java.rmi.RMISecurityManager;
import java.rmi.RemoteException;

import org.knopflerfish.service.log.LogRef;
import org.osgi.framework.BundleContext;

import com.ak.osgi.service.rmi.http.StubDownloader;
import com.ak.osgi.service.rmi.utility.BundleProperties;

/**
 * The <tt>Activator</tt> class is a start point of the bundle deploying 
 * 
 * @version 1.0.0
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 */
public class Activator implements com.ak.osgi.service.rmi.Activator
{
  private static BundleContext bc = null;
  private static RemoteServer rmiGate = null;
  private static StubDownloader downLoader = null;
  static LogRef log;
  /**
   *@param context
   *@throws Exception
   *@see org.osgi.framework.BundleActivator#start(org.osgi.framework.BundleContext)
   */ 
  public void start( BundleContext context ) throws Exception
  {
    Activator.bc = context;
    Activator.log = new LogRef( bc );
    
    if (System.getSecurityManager() == null) 
    {
      System.setSecurityManager(new RMISecurityManager());
      log.info( "New RMI security manager is set." );
    }
    
    downLoader = new StubDownloader( bc );
    downLoader.register();

    BundleProperties bp = new BundleProperties( this );
        
    try
    {
        rmiGate = new RemoteServer( this );
    }
    catch( RemoteException e )
    {
      log.error( "Can not make an instance of RMIGateImpl." );
      throw new Exception( "RemoteException : can not create RMIGate" );
    }
    if( !rmiGate.setup( bp.getLocalRegistryPort() ) )
    {
      log.error( "Can not setup RMIGate." );
      throw new Exception( "can not setup RMIGate" );
    }
    rmiGate.open();
    log.info( "RMI Gate start." );
  }

  /**
   * @see org.osgi.framework.BundleActivator#stop(org.osgi.framework.BundleContext)
   */
  public void stop( BundleContext context ) throws Exception
  {
// closing
    rmiGate.close();
    downLoader.unregister();
    log.info( "RMI Gate stop." );
    log.close();
// for GC
    Activator.bc = null;
    downLoader = null;
    rmiGate = null;
    log = null;
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.Activator#getLogger()
   */ 
  
  public LogRef getLogger()
  {
    return log;
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.Activator#getBundleContext()
   */ 
  
  public BundleContext getBundleContext()
  {
    return bc;
  }

}
