/* Created on Apr 10, 2006 */
/**
   Copyright (C) 2006 by AKrasnopolski (Alexei Krasnopolski)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/

package com.ak.osgi.service.rmi.infobean;

import java.io.Serializable;

import org.osgi.framework.Bundle;
import org.osgi.framework.ServiceReference;

import com.ak.osgi.service.rmi.remotefw.BundleInfoBean;
import com.ak.osgi.service.rmi.remotefw.BundleShortInfoBean;
import com.ak.osgi.service.rmi.remotefw.ServiceReferenceInfoBean;

/**
 * The <tt>BundleInfoBeanImpl</tt> class 
 * <p>
 * @version 1.0.0
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 */
public class BundleInfoBeanImpl extends BundleShortInfoBeanImpl implements BundleInfoBean
{
  /**
   *  Field serialVersionUID is type of <tt>long</tt>
   */
  private static final long serialVersionUID = 1L;
  ServiceReferenceInfoBean [] registeredServices; 
  ServiceReferenceInfoBean [] servicesInUse; 

  /**
   * @param bundle
   */
  public BundleInfoBeanImpl( Bundle bundle )
  {
    super( bundle );
    ServiceReference [] srfs = bundle.getRegisteredServices();
    if( srfs != null )
    {
      registeredServices = new ServiceReferenceInfoBean[srfs.length];
      for( int i = 0; i < srfs.length; i++ )
      {
        ServiceReferenceInfoBean srfinfo = new ServiceReferenceInfoBeanImpl( srfs[i] );
        registeredServices[i] = srfinfo;
      }
    }
    else
      registeredServices = new ServiceReferenceInfoBean[0];
    
    srfs = bundle.getServicesInUse();
    if( srfs != null)
    {
      servicesInUse = new ServiceReferenceInfoBean[srfs.length];
      for( int i = 0; i < srfs.length; i++ )
      {
        ServiceReferenceInfoBean srfinfo = new ServiceReferenceInfoBeanImpl( srfs[i] );
        servicesInUse[i] = srfinfo;
      }
    }
    else
      servicesInUse = new ServiceReferenceInfoBean[0];
  }
   
  /**
   *@return
   *@see com.ak.osgi.service.rmi.remotefw.BundleInfoBean#getRegisteredServices()
   */
  public ServiceReferenceInfoBean [] getRegisteredServices()
  {
    return registeredServices;
  }

  public void setRegisteredServices( ServiceReferenceInfoBean [] registeredServices )
  {
    this.registeredServices = registeredServices;
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.remotefw.BundleInfoBean#getServicesInUse()
   */

  public ServiceReferenceInfoBean [] getServicesInUse()
  {
    return servicesInUse;
  }

  public void setServicesInUse( ServiceReferenceInfoBean [] servicesInUse )
  {
    this.servicesInUse = servicesInUse;
  }

}
