/* Created on Apr 12, 2006 */
/**
   Copyright (C) 2006 by AKrasnopolski (Alexei Krasnopolski)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/

package com.ak.osgi.service.rmi.infobean;

import java.util.Dictionary;
import java.util.Hashtable;

import org.osgi.framework.Bundle;
import org.osgi.framework.ServiceReference;

import com.ak.osgi.service.rmi.RmiConstants;
import com.ak.osgi.service.rmi.remotefw.BundleInfoBean;
import com.ak.osgi.service.rmi.remotefw.BundleShortInfoBean;
import com.ak.osgi.service.rmi.remotefw.ServiceReferenceInfoBean;

/**
 * The <tt>ServiceReferenceInfoBeanImpl</tt> class 
 * <p>
 * @version 1.0.0
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 */
public class ServiceReferenceInfoBeanImpl implements ServiceReferenceInfoBean
{
  /**
   *  Field serialVersionUID is type of <tt>long</tt>
   */
  private static final long serialVersionUID = 1L;
  Dictionary properties;
  BundleShortInfoBean bundle;
  BundleShortInfoBean [] usingBundles;
  
  public ServiceReferenceInfoBeanImpl( ServiceReference srfr )
  {
    String [] keys = srfr.getPropertyKeys();
    String key;
    properties = new Hashtable();
    if( keys != null )
    {
      for( int i = 0; i < keys.length; i++ )
      {
        key = keys[i];
        properties.put( key, srfr.getProperty( key ) );
      }
    }
    
    usingBundles = new BundleShortInfoBean [0];
    Bundle bndl = srfr.getBundle();
    if( bndl != null )
    {
      bundle = new BundleShortInfoBeanImpl( bndl );
      Bundle [] bndls = srfr.getUsingBundles();
      if( bndls != null )
      {
        usingBundles = new BundleShortInfoBean [bndls.length];
        for( int i = 0; i < bndls.length; i++ )
        {
          BundleShortInfoBean bndlinfo = new BundleShortInfoBeanImpl( bndls[i] );
          usingBundles[i] = bndlinfo;
        }
      }
    }
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.remotefw.ServiceReferenceInfoBean#getProperties()
   */

  public Dictionary getProperties()
  {
    return properties;
  }

  /**
   *@param dic
   *@see com.ak.osgi.service.rmi.remotefw.ServiceReferenceInfoBean#setProperties(java.util.Dictionary)
   */

  public void setProperties( Dictionary dic )
  {
    properties = dic;
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.remotefw.ServiceReferenceInfoBean#getBundle()
   */

  public BundleShortInfoBean getBundle()
  {
    return bundle;
  }

  /**
   *@param b
   *@see com.ak.osgi.service.rmi.remotefw.ServiceReferenceInfoBean#setBundle(com.ak.osgi.service.rmi.remotefw.BundleInfoBean)
   */

  public void setBundle( BundleInfoBean b )
  {
    bundle = b;
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.remotefw.ServiceReferenceInfoBean#getUsingBundles()
   */

  public BundleShortInfoBean [] getUsingBundles()
  {
    return usingBundles;
  }

  /**
   *@param ub
   *@see com.ak.osgi.service.rmi.remotefw.ServiceReferenceInfoBean#setUsingBundles(com.ak.osgi.service.rmi.remotefw.BundleShortInfoBean[])
   */

  public void setUsingBundles( BundleShortInfoBean [] ub )
  {
    usingBundles = ub;
  }

}
