/* Created on Apr 5, 2006 */
/**
   Copyright (C) 2006 by AKrasnopolski (Alexei Krasnopolski)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/

package com.ak.osgi.service.rmi.remotefw;

import org.osgi.framework.ServicePermission;
import org.osgi.framework.ServiceReference;
import org.osgi.framework.ServiceRegistration;


/**
 * The <tt>BundleInfoBean</tt> interface 
 * <p>
 * @version 1.0.0
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 */
public interface BundleInfoBean extends BundleShortInfoBean
{

  /**
     * Returns this bundle's <tt>ServiceReference</tt> list for all
     * services it has registered or <tt>null</tt> if this bundle
     * has no registered services.
     *
     * <p>If the Java runtime supports permissions, a <tt>ServiceReference</tt> object to a
     * service is included in the returned list only if the
     * caller has the <tt>ServicePermission</tt> to get the service
     * using at least one of the named classes the service was registered under.
     *
     * <p>The list is valid at the time of the call to this method, however, as the Framework is a very dynamic
     * environment, services can be modified or unregistered at anytime.
     *
     * @return An array of <tt>ServiceReference</tt> objects or <tt>null</tt>.
     * @exception java.lang.IllegalStateException If this bundle has been uninstalled.
     * @see ServiceRegistration
     * @see ServiceReference
     * @see ServicePermission
     */
  public abstract ServiceReferenceInfoBean[] getRegisteredServices();
  public abstract void setRegisteredServices( ServiceReferenceInfoBean[] rs );

  /**
     * Returns this bundle's <tt>ServiceReference</tt> list for all
     * services it is using or returns <tt>null</tt> if this bundle is not using any services.
     * A bundle is considered to be using a service if its use count for that service is greater than zero.
     *
     * <p>If the Java Runtime Environment supports permissions,
     * a <tt>ServiceReference</tt> object to a service is included in the returned list only if the
     * caller has the <tt>ServicePermission</tt> to get the service
     * using at least one of the named classes the service was registered under.
     * <p>The list is valid at the time of the call to this method, however, as the Framework is a very dynamic
     * environment, services can be modified or unregistered at anytime.
     *
     * @return An array of <tt>ServiceReference</tt> objects or <tt>null</tt>.
     * @exception java.lang.IllegalStateException If this bundle has been uninstalled.
     * @see ServiceReference
     * @see ServicePermission
     */
  public abstract ServiceReferenceInfoBean[] getServicesInUse();
  public abstract void setServicesInUse( ServiceReferenceInfoBean[] us );

}
