/* Created on Apr 5, 2006 */
/**
   Copyright (C) 2006 by AKrasnopolski (Alexei Krasnopolski)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/

package com.ak.osgi.service.rmi.remotefw;

import java.io.Serializable;

import org.osgi.framework.BundleContext;

/**
 * The <tt>BundleInfoBean</tt> class 
 * <p>
 * @version 1.0.0
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 */
public interface BundleShortInfoBean extends Serializable
{
  /**
     * Returns this bundle's current state.
     *
     * <p>A bundle can be in only one state at any time.
     *
     * @return An element of <tt>UNINSTALLED</tt>, <tt>INSTALLED</tt>,
     * <tt>RESOLVED</tt>, <tt>STARTING</tt>, <tt>STOPPING</tt>,
     * <tt>ACTIVE</tt>.
     */
  public abstract int getState();
  public abstract void setState( int s );

  /**
     * Returns this bundle's identifier. The bundle is assigned a unique identifier by the Framework
     * when it is installed in the OSGi environment.
     *
     * <p>A bundle's unique identifier has the following attributes:
     * <ul>
     * <li>Is unique and persistent.
     * <li>Is a <tt>long</tt>.
     * <li>Its value is not reused for another bundle, even after the bundle is uninstalled.
     * <li>Does not change while the bundle remains installed.
     * <li>Does not change when the bundle is updated.
     * </ul>
     *
     * <p>This method will continue to return this bundle's unique identifier
     * while this bundle is in the <tt>UNINSTALLED</tt> state.
     *
     * @return The unique identifier of this bundle.
     */
  public abstract long getBundleId();
  public abstract void setBundleId( long id );

  /**
     * Returns this bundle's location identifier.
     *
     * <p>The bundle location identifier is the location passed to
     * {@link BundleContext#installBundle}when a bundle is installed.
     *
     * <p>This method will continue to return this bundle's location
     * identifier while this bundle is in the <tt>UNINSTALLED</tt> state.
     *
     * @return The string representation of this bundle's location identifier.
     * @exception java.lang.SecurityException If the caller does not have
     * the appropriate <tt>AdminPermission</tt>, and the Java Runtime Environment
     * supports permissions.
     */
  public abstract String getLocation();
  public abstract void setLocation( String loc );

  public abstract String getName();
  public abstract void setName( String name );
}
