/*
 * Created on Aug 23, 2005
 *
 */
/**
   Copyright (C) 2006 by Alexei Krasnopolski

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/
package com.ak.osgi.service.rmi.remotefw;

import java.rmi.Remote;
import java.rmi.RemoteException;


/**
 * The <tt>RMIEntrant</tt> interface represents client functionality to
 * <tt>RMIGate</tt> object on remote framework. 
 * 
 * @version 1.0.0
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 */
public interface RMIEntrant extends Remote
{
  /**
   * <tt>RMIGate</tt> object invokes this method to register remote service <tt>rmiService</tt> 
   * running on remote framework to local framework.
   * 
   *@param bean
   *          java bean instance of <tt>RMIServiceBean</tt> that contents:<br>
   *        hash Code - unique id (on server FW) of the remote service;<br> 
   *        clazzes -  List of interfaces for <tt>rmiService</tt>;<br>
   *        rmiService - Remote service to register on client framework;<br>
   *        properties - Property hashtable for the remote service.
   *@throws RemoteException
   */ 
//  public void registerRMIService( int hashCode, String [] clazzes, Remote rmiService, Dictionary properties ) throws RemoteException;
  public void registerRMIService( RMIServiceBean bean ) throws RemoteException;
  /**
   * <tt>RMIGate</tt> object invokes this method to unregister remote service 
   * running on remote framework from local framework.
   * 
   *@param hashCode
   *          Hashtable key of unregistering remote service.
   *@throws RemoteException
   */ 
  public void unregisterRMIService( int hashCode ) throws RemoteException;
}
