/* Created on Apr 5, 2006 */
/**
   Copyright (C) 2006 by AKrasnopolski (Alexei Krasnopolski)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/

package com.ak.osgi.service.rmi.remotefw;

import java.io.Serializable;
import java.util.Dictionary;

import org.osgi.framework.BundleContext;


/**
 * The <tt>ServiceReferenceInfoBean</tt> class 
 * <p>
 * @version 1.0.0
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 */
public interface ServiceReferenceInfoBean extends Serializable
{
  /**
   * Returns the property value to which the specified property key is mapped in the
   * properties <tt>Dictionary</tt> object of the service referenced by this <tt>ServiceReference</tt> object.
   *
   * <p>Property keys are case-insensitive.
   *
   * <p>This method must continue to return property values after the service has been unregistered.
   * This is so references to unregistered services (for example, <tt>ServiceReference</tt> objects
   * stored in the log) can still be interrogated.
   *
   * @param key The property key.
   * @return The property value to which the key is mapped; <tt>null</tt> if there is no property
   * named after the key.
   */
  public abstract Dictionary getProperties();
  public abstract void setProperties( Dictionary dic );

  /**
   * Returns the bundle that registered the service referenced by this <tt>ServiceReference</tt> object.
   *
   * <p>This method will always return <tt>null</tt> when the service has been unregistered.
   * This can be used to determine if the service has been unregistered.
   *
   * @return The bundle that registered the service referenced by this <tt>ServiceReference</tt> object;
   * <tt>null</tt> if that service has already been unregistered.
   * @see BundleContext#registerService
   */
  public abstract BundleShortInfoBean getBundle();
  public abstract void setBundle( BundleInfoBean b );

  /**
   * Returns the bundles that are using the service referenced by this <tt>ServiceReference</tt> object.
   * Specifically, this method returns the bundles whose usage count for that service is greater
   * than zero.
   *
   * @return An array of bundles whose usage count for the service referenced by
   * this <tt>ServiceReference</tt> object is greater than zero; <tt>null</tt> if no
   * bundles are currently using that service.
   *
   * @since 1.1
   */
  public abstract BundleShortInfoBean[] getUsingBundles();
  public abstract void setUsingBundles( BundleShortInfoBean[] ub );

}
