/* Created on Apr 12, 2006 */
/**
   Copyright (C) 2006 by AKrasnopolski (Alexei Krasnopolski)

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/

package com.ak.osgi.service.rmi.serviceimpl.rmifwcontext;

import java.rmi.RemoteException;
import java.rmi.server.UnicastRemoteObject;
import java.util.Dictionary;
import java.util.Hashtable;

import org.osgi.framework.Bundle;
import org.osgi.framework.BundleContext;
import org.osgi.framework.BundleException;
import org.osgi.framework.Constants;
import org.osgi.framework.ServiceRegistration;

import com.ak.osgi.service.rmi.RmiConstants;
import com.ak.osgi.service.rmi.infobean.BundleInfoBeanImpl;
import com.ak.osgi.service.rmi.infobean.BundleShortInfoBeanImpl;
import com.ak.osgi.service.rmi.interfaces.rmifwcontext.RemoteOSGiFramework;
import com.ak.osgi.service.rmi.remotefw.BundleInfoBean;
import com.ak.osgi.service.rmi.remotefw.BundleShortInfoBean;

/**
 * The <tt>RemoteOSGiFrameworkImpl</tt> class 
 * <p>
 * @version 1.0.0
 * @author <a href="mailto:krasnop@bellsouth.net">Alexei Krasnopolski</a>
 */
public class RemoteOSGiFrameworkImpl extends UnicastRemoteObject implements RemoteOSGiFramework
{
  /**
   *  Field serialVersionUID is type of <tt>long</tt>
   */
  private static final long serialVersionUID = 4325728530865382489L;
  BundleContext bc;
  ServiceRegistration sreg;
  /**
   * 
   */
  public RemoteOSGiFrameworkImpl( BundleContext bc ) throws RemoteException
  {
    this.bc = bc;
    Dictionary props = new Hashtable();
    props.put( RmiConstants.KEY_RMISERVICE_LOC, "Framework context" );
    sreg = bc.registerService( RemoteOSGiFramework.class.getName(), this, props );
  }

  /**
   *@return
   *@see com.ak.osgi.service.rmi.interfaces.rmifwcontext.RemoteOSGiFramework#getBundles()
   */

  public BundleShortInfoBean [] getBundles() throws RemoteException
  {
    Bundle [] bundles;
    try
    {
      bundles = bc.getBundles();
    }
    catch( IllegalStateException e )
    {
      throw new RemoteException( e.getMessage() );
    }
    BundleShortInfoBean [] result = new BundleShortInfoBean [bundles.length];
    
    for( int i = 0; i < result.length; i++ )
    {
      BundleShortInfoBean binfo = new BundleShortInfoBeanImpl( bundles[i] );
      result[i] = binfo;
    }
    
    return result;
  }
  
  public void dispose()
  {
    sreg.unregister();
  }

  /**
   *@param id
   *@return
   *@throws RemoteException
   *@see com.ak.osgi.service.rmi.interfaces.rmifwcontext.RemoteOSGiFramework#getBundle(long)
   */ 
  
  public BundleInfoBean getBundle( long id ) throws RemoteException
  {
    Bundle bundle;
    try
    {
      bundle = bc.getBundle( id );
    }
    catch( IllegalStateException e )
    {
      throw new RemoteException( e.getMessage() );
    }
    BundleInfoBean binfo = new BundleInfoBeanImpl( bundle );
    return binfo;
  }

  /**
   *@return
   *@throws RemoteException
   *@see com.ak.osgi.service.rmi.interfaces.rmifwcontext.RemoteOSGiFramework#getProperties()
   */ 
  static final String [] frameworkKeys = new String []
    {
      Constants.FRAMEWORK_VERSION,
      Constants.FRAMEWORK_VENDOR,
      Constants.FRAMEWORK_LANGUAGE,
      Constants.FRAMEWORK_OS_NAME,
      Constants.FRAMEWORK_OS_VERSION,
      Constants.FRAMEWORK_PROCESSOR,
      Constants.FRAMEWORK_EXECUTIONENVIRONMENT
    };
  
  public Dictionary getProperties() throws RemoteException
  {
    Dictionary props = new Hashtable();
    for( int i = 0; i < frameworkKeys.length; i++ )
    {
      String key = frameworkKeys[i];
      Object value = bc.getProperty( key );
      props.put( key, ((value == null)?"":value) );
    }
    return props;
  }

  /**
   *@param id
   *@throws RemoteException
   *@see com.ak.osgi.service.rmi.interfaces.rmifwcontext.RemoteOSGiFramework#startBundle(long)
   */ 
  
  public void startBundle( long id ) throws RemoteException
  {
    try
    {
      bc.getBundle( id ).start();
    }
    catch( BundleException e )
    {
      throw new RemoteException( "Can not start the bundle" );
    }
  }

  /**
   *@param id
   *@throws RemoteException
   *@see com.ak.osgi.service.rmi.interfaces.rmifwcontext.RemoteOSGiFramework#stopBundle(long)
   */ 
  
  public void stopBundle( long id ) throws RemoteException
  {
    try
    {
      bc.getBundle( id ).stop();
    }
    catch( BundleException e )
    {
      throw new RemoteException( "Can not stop the bundle" );
    }
  }

}
