/*
 * Created on Mar 25, 2006
 *
 */
/**
   Copyright (C) 2006 by Alexei Krasnopolski

   Licensed under the Apache License, Version 2.0 (the "License");
   you may not use this file except in compliance with the License.
   You may obtain a copy of the License at

       http://www.apache.org/licenses/LICENSE-2.0

   Unless required by applicable law or agreed to in writing, software
   distributed under the License is distributed on an "AS IS" BASIS,
   WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
   See the License for the specific language governing permissions and
   limitations under the License. 
*/
package com.ak.osgi.service.rmi.utility;

import java.io.IOException;
import java.net.URL;
import java.util.Properties;

import org.knopflerfish.service.log.LogRef;
import org.osgi.framework.BundleContext;

import com.ak.osgi.service.rmi.RmiConstants;

/**
 * <h5>
 * </h5>
 *
 * @author <a href="mailto:akrasnopolski@incomm.com">Alexei Krasnopolski</a>
 * @version 1.0.0
 */
public class BundleProperties
{
  private BundleContext bc = null;
  protected LogRef log;

  private int localRegistryPort;
  private int remoteRegistryPort;
  private String remoteHost;

  public BundleProperties( com.ak.osgi.service.rmi.Activator $activator )
  {
    bc = $activator.getBundleContext();
    log = $activator.getLogger();
//  Get properties from System (from props.arg file or from 'java -D...' command)
    String locPort = System.getProperty( RmiConstants.KEY_LOCAL_REGISTRY_PORT );
    remoteHost = System.getProperty( RmiConstants.KEY_REMOTE_REGISTRY_HOST );
    String remPort = System.getProperty( RmiConstants.KEY_REMOTE_REGISTRY_PORT );
    localRegistryPort = 1199;
    remoteRegistryPort = 1299;
    if( locPort == null &&  remoteHost == null && remPort == null )
    {
// Get properties from inside bundle jar
      Properties props = new Properties();
      URL url = bc.getBundle().getResource( "rmi.properties" );
      try
      {
        props.load( url.openStream() );
      }
      catch( NullPointerException npe )
      {
        log.error( "Can not read properties from file 'rmi.properties'. Default configuration is set." );
      }
      catch( IOException e1 )
      {
        log.error( "Can not read properties from file 'rmi.properties'. Default configuration is set." );
      }
      catch( IllegalArgumentException e2 )
      {
        log.error( "syntax error in properties file. Default configuration is set." );
      }
      locPort = props.getProperty( RmiConstants.KEY_LOCAL_REGISTRY_PORT, "1199" );
      remoteHost = props.getProperty( RmiConstants.KEY_REMOTE_REGISTRY_HOST );
      remPort = props.getProperty( RmiConstants.KEY_REMOTE_REGISTRY_PORT, "1299" );
    }
    else
    {
//    set from System properties 
      if( locPort == null )
        locPort = "1199";
//      if( remoteHost == null )
//        remoteHost = "localhost";
      if( remPort == null )
        remPort = "1299";
    }
    try
    { 
      localRegistryPort = Integer.parseInt( locPort );
    }
    catch( NumberFormatException e1 ){}

    try
    {
      remoteRegistryPort = Integer.parseInt( remPort );
    }
    catch( NumberFormatException e1 ){}
    if( remoteHost != null )
    {
      remoteHost = remoteHost.trim();
      if( remoteHost.length() == 0 )
        remoteHost = null;
    }
    log.info( "Bundle properties: local port=" + localRegistryPort 
        + "; remote port=" + remoteRegistryPort + "; remote host=" + remoteHost );
  }

  /**
   * @return Returns the localRegistryPort.
   */
  public int getLocalRegistryPort()
  {
    return localRegistryPort;
  }

  /**
   * @return Returns the remoteHost.
   */
  public String getRemoteHost()
  {
    return remoteHost;
  }

  /**
   * @return Returns the remoteRegistryPort.
   */
  public int getRemoteRegistryPort()
  {
    return remoteRegistryPort;
  }
}
