/*
 * Created on Jun 4, 2006
 */
package com.ak.osgi.service.rmi.utility;

import java.lang.reflect.Method;
import java.rmi.Remote;
import java.rmi.server.RMIClassLoader;
import java.rmi.server.RemoteObject;
import java.rmi.server.RemoteServer;
import java.rmi.server.ServerNotActiveException;
import org.knopflerfish.service.log.LogRef;
import org.osgi.framework.ServiceReference;

/**
 * <h5> </h5>
 * 
 * @author <a href="mailto:akrasnopolski@incomm.com">Alexei Krasnopolski</a>
 * @version 1.0.0
 */
public class DebugLog
{

  public static void logRemoteInstance( LogRef log, String name, Remote robj )
  {
    RemoteObject obj = (RemoteObject)robj;
    String separator = "\r\t";
    ClassLoader cl = obj.getClass().getClassLoader();
    StringBuffer text = new StringBuffer();
    text.append( name + " stub = " + obj + separator );
    text.append( "  -- class loader = " + cl + separator );
    text.append( "  -- annotation = " + RMIClassLoader.getClassAnnotation( obj.getClass() )
        + separator );
    try
    {
      text.append( "  -- client host = " + RemoteServer.getClientHost() + separator );
    }
    catch( ServerNotActiveException e )
    {}
    text.append( "  -- parent class loader = " + cl.getParent() + separator );
    log.debug( text.toString() );
    // log.debug( name + " stub = " + obj );
    // log.debug( "class loader = " + cl );
    // log.debug( "parent class loader = " + cl.getParent() );
  }

  public static void logServiceProperties( ServiceReference reference )
  {
    String [] keys = reference.getPropertyKeys();
    System.out.println( "************ properties **********" );
    for( int i = 0; i < keys.length; i++ )
    {
      String key = keys[i];
      Object value = reference.getProperty( key );
      if( value instanceof String [] )
      {
        String [] values = (String [])value;
        System.out.println( "entry[" + i + "] : " + key + " = " + value );
        for( int j = 0; j < values.length; j++ )
          System.out.println( "        [" + j + "] = " + values[j] );
      }
      else
        System.out.println( "entry[" + i + "] : " + key + " = " + value );
    }
  }

  // public static void debugDump( RMIGate $gate )
  // {
  // RemoteOSGiFramework remoteContext;
  // try
  // {
  // remoteContext = $gate.getRemoteContext();
  // if( remoteContext == null )
  // {
  // log.error( "can not get 'RemoteOSGiFramework' service: remoteContext = null !!!" );
  // }
  // else
  // {
  // dumpClassInfo( remoteContext );
  // BundleShortInfoBean binfo;
  // BundleShortInfoBean [] binfos;
  // binfo = remoteContext.getBundle( 1 );
  // System.out.println( binfo.getName()
  // + " [" + binfo.getBundleId() + "] "
  // + " loc : " + binfo.getLocation() );
  // binfos = remoteContext.getBundles();
  // for( int i = 0; i < binfos.length; i++ )
  // {
  // System.out.println( binfos[i].getName()
  // + " [" + binfos[i].getBundleId() + "] "
  // + " loc : " + binfos[i].getLocation() );
  // }
  // }
  // }
  // catch( RemoteException e1 )
  // {
  // log.error( "can not use remote service", e1 );
  // }
  // }

  public static void dumpClassInfo( Object o )
  {
    System.out.println( " -- object is " + ((o == null) ? "null" : "not null") );
    if( o != null )
    {
      Class stub_class = o.getClass();
      dumpInterfaceInfo( stub_class );
    }
  }

  public static void dumpInterfaceInfo( Class clss )
  {
    ClassLoader loader = clss.getClassLoader();
    Class [] ifaces = clss.getInterfaces();
    Method [] methods = clss.getMethods();
    Package pck = clss.getPackage();
    System.out.println( "\n -- class name : " + clss.getName() + "\n -- package name : "
        + ((pck == null) ? "null" : pck.getName()) + "\n -- classLoader name : "
        + ((loader == null) ? "null" : loader.getClass().getName()) );
    System.out.println( "  Interfaces : " );
    for( int i = 0; i < ifaces.length; i++ )
      System.out.println( i + ">> " + ifaces[i].getName() );
    // System.out.println( " Methods : " );
    // for( int i = 0; i < methods.length; i++ )
    // System.out.println( i + ">> " + methods[i].getName() + "();" );
  }
}
